@@ -35,13 +35,11 @@ use bytes;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.03';
 
 use Carp qw/carp croak verbose/;
-use Data::Dumper;
 
 use D64::Disk::Image qw(:all);
-use D64::Disk::Dir;
 
 # File type names:
 our @file_types = qw/del seq prg usr rel cbm dir ???/;
@@ -192,24 +190,6 @@ sub get_type {
     return $file_type;
 }
 
-=head2 set_type
-
-Set the actual filetype:
-
-  my $type = T_DEL;
-  $entryObj->set_type($type);
-
-Sets the actual filetype as a symbollic type name, the possibilities here are: C<T_DEL>, C<T_SEQ>, C<T_PRG>, C<T_USR>, C<T_REL>, C<T_CBM>, and C<T_DIR>.
-
-=cut
-
-sub set_type {
-    my ($self, $type) = @_;
-    croak "An illegal file type: ${type}" unless grep { $type == $_ } values %D64::Disk::Dir::file_type_constants;
-    $self->{'DETAILS'}->{'TYPE'} = $type;
-    return $type;
-}
-
 =head2 get_closed
 
 Get "Closed" flag (when not set produces "*", or "splat" files):
@@ -226,25 +206,6 @@ sub get_closed {
     return $closed ? 1 : 0;
 }
 
-=head2 set_closed
-
-Set "Closed" flag:
-
-  $entryObj->set_closed(1);
-
-Clear "Closed" flag:
-
-  $entryObj->set_closed(0);
-
-=cut
-
-sub set_closed {
-    my ($self, $closed) = @_;
-    croak "An illegal closed flag: ${closed}" unless $closed == 0 || $closed == 1;
-    $self->{'DETAILS'}->{'CLOSED'} = $closed;
-    return $closed;
-}
-
 =head2 get_locked
 
 Get "Locked" flag (when set produces ">" locked files):
@@ -275,20 +236,6 @@ sub get_track {
     return $track;
 }
 
-=head2 set_track
-
-Set track location of first sector of file:
-
-  $entryObj->get_track($track);
-
-=cut
-
-sub set_track {
-    my ($self, $track) = @_;
-    $self->{'DETAILS'}->{'TRACK'} = $track;
-    return $track;
-}
-
 =head2 get_sector
 
 Get sector location of first sector of file:
@@ -303,20 +250,6 @@ sub get_sector {
     return $sector;
 }
 
-=head2 set_sector
-
-Set sector location of first sector of file:
-
-  $entryObj->set_sector($sector);
-
-=cut
-
-sub set_sector {
-    my ($self, $sector) = @_;
-    $self->{'DETAILS'}->{'SECTOR'} = $sector;
-    return $sector;
-}
-
 =head2 get_name
 
 Get 16 character filename (in PETASCII, padded with $A0):
@@ -433,36 +366,26 @@ sub get_bytes {
 
 Print entry details to any opened file handle (the standard output by default):
 
-  $entryObj->print_entry($fh, { verbose => $verbose });
+  $entryObj->print_entry($fh);
 
 This method is subsequently invoked for each single entry while printing an entire directory with D64::Disk::Dir module.
 
-C<verbose> defaults to false (changing it to true will additionally print out file's track and sector values).
-
 =cut
 
 sub print_entry {
-    my ($self, $fh, $args) = @_;
+    my $self = shift;
+    my $fh = shift;
     $fh = *STDOUT unless defined $fh;
-    $args = {} unless defined $args;
-    my $verbose = $args->{verbose};
     # Get detailed file information stored within this object instance:
     my $type = $self->get_type();
     my $closed = $self->get_closed() ? ord ' ' : ord '*';
     my $locked = $self->get_locked() ? ord '<' : ord ' ';
     my $size = $self->get_size();
-    my $track = sprintf '%2d', $self->get_track();
-    my $sector = sprintf '%2d', $self->get_sector();
     # Get filename convert to ASCII and add quotes:
     my $name = $self->get_name(1);
     my $quotename = sprintf "\"%s\"", $name;
     # Print directory entry:
-    if ($verbose) {
-      printf $fh "%-4d  %-18s%c%s%c %s %s\n", $size, $quotename, $closed, $type, $locked, $track, $sector;
-    }
-    else {
-      printf $fh "%-4d  %-18s%c%s%c\n", $size, $quotename, $closed, $type, $locked;
-    }
+    printf $fh "%-4d  %-18s%c%s%c\n", $size, $quotename, $closed, $type, $locked;
 }
 
 =head1 BUGS
@@ -483,7 +406,7 @@ Pawel Krol, E<lt>pawelkrol@cpan.orgE<gt>.
 
 =head1 VERSION
 
-Version 0.05 (2023-05-14)
+Version 0.03 (2013-02-16)
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -494,21 +417,12 @@ All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
-=over
-
-=item *
-
-Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
-
-=item *
-
-Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-=back
+- Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+- Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-diskimage.c website: L<https://paradroid.automac.se/diskimage/>
+diskimage.c website: L<http://www.paradroid.net/diskimage/>
 
 =cut
 
